Enum CallIntent
#[non_exhaustive]pub enum CallIntent {
Audio,
Video,
}Available on crate features
unstable-msc4310 and unstable-msc4075 only.Expand description
Indication of whether the call is a “audio” or “video”(+audio) call.
This type can hold an arbitrary string. To build this with a custom value, convert it from a
string with ::from() / .into(). To check for values that are not available as a
documented variant here, use its string representation, obtained through
.as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Audio
Soft indication from the sender that the call is intended for audio.
Video
Soft indication from the sender that the call is intended for video. Hence that the receiver should start with camera enabled.
Implementations
impl CallIntent
impl CallIntent