Enum NotificationType
#[non_exhaustive]pub enum NotificationType {
Ring,
Notification,
}Available on crate features
unstable-msc4310 and unstable-msc4075 only.Expand description
How this notification should notify the receiver.
This type can hold an arbitrary string. To build this with a custom value, convert it from a
string with ::from() / .into(). To check for values that are not available as a
documented variant here, use its string representation, obtained through
.as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Ring
The receiving client should ring with an audible sound.
Notification
The receiving client should display a visual notification.
Implementations
impl NotificationType
impl NotificationType